@@ -1,5 +1,4 @@
 package TestApp;
-our $VERSION = '0.002002';
 use Moose;
 use namespace::autoclean;
 
@@ -7,7 +6,10 @@ use Catalyst;
 extends 'Catalyst';
 
 __PACKAGE__->config(
-    default_view => 'HTML'
+    default_view => 'HTML',
+    'View::HTML::Foo' => {
+        test_arg => 111,
+    },
 );
 
 __PACKAGE__->setup;
