@@ -1,8 +1,12 @@
 package TestApp::View::HTML::Foo;
-our $VERSION = '0.002002';
 use Moose;
 use namespace::autoclean;
 
+has test_arg => (
+    is => 'ro',
+    required => 1,
+);
+
 sub bar {
     my ($self, $stash) = @_;
     $_->select('#name')->replace_content($stash->{name});
