@@ -1,9 +1,13 @@
 package TestApp::View::HTML::Root;
-our $VERSION = '0.002002';
 use Moose;
-use Method::Signatures::Simple;
 
-method main ($stash) {
+sub main {
+    my ($self, $stash) = @_;
+    $_->select("#name")->replace_content($stash->{name});
+}
+
+sub direct_render {
+    my ($self, $stash) = @_;
     $_->select("#name")->replace_content($stash->{name});
 }
 
